ExecutionManager

Enum ExecutionManager 

pub enum ExecutionManager<F> {
    NativeWhenPossible,
    AlwaysWasm(BackendTrustLevel),
    Both(F),
    NativeElseWasm,
}
Like ExecutionStrategy only it also stores a handler in case of consensus failure.

Variants



NativeWhenPossible

Execute with the native equivalent if it is compatible with the given wasm module; otherwise fall back to the wasm.



AlwaysWasm(BackendTrustLevel)

Use the given wasm module. The backend on which code is executed code could be trusted to provide all storage or not (i.e. the light client cannot be trusted to provide for all storage queries since the storage entries it has come from an external node).



Both(F)

Run with both the wasm and the native variant (if compatible). Call F in the case of any discrepancy.



NativeElseWasm

First native, then if that fails or is not possible, wasm.