ChangesTrieBuildCache

Struct ChangesTrieBuildCache 

pub struct ChangesTrieBuildCache<H, N> { /* private fields */ }
Changes trie build cache.

Helps to avoid read of changes tries from the database when digest trie is built. It holds changed keys for every block (indexed by changes trie root) that could be referenced by future digest items. For digest entries it also holds keys covered by this digest. Entries for top level digests are never created, because they’ll never be used to build other digests.

Entries are pruned from the cache once digest block that is using this entry is inserted (because digest block will includes all keys from this entry). When there’s a fork, entries are pruned when first changes trie is inserted.

Implementations

Source

impl<H, N> BuildCache<H, N>
where N: Eq + Hash, H: Eq + Hash + Clone,

pub fn new() -> Self

Create new changes trie build cache.

pub fn get( &self, root: &H, ) -> Option<&HashMap<Option<PrefixedStorageKey>, HashSet<StorageKey>>>

Get cached changed keys for changes trie with given root.

pub fn with_changed_keys( &self, root: &H, functor: &mut dyn FnMut(&HashMap<Option<PrefixedStorageKey>, HashSet<StorageKey>>), ) -> bool

Execute given functor with cached entry for given block. Returns true if the functor has been called and false otherwise.

pub fn perform(&mut self, action: CacheAction<H, N>)

Insert data into cache.