pub struct StorageChanges<Transaction, H: Hasher, N: BlockNumber> {
pub main_storage_changes: StorageCollection,
pub child_storage_changes: ChildStorageCollection,
pub offchain_storage_changes: OffchainChangesCollection,
pub transaction: Transaction,
pub transaction_storage_root: H::Out,
pub changes_trie_transaction: Option<ChangesTrieTransaction<H, N>>,
}Expand description
A storage changes structure that can be generated by the data collected in OverlayedChanges.
This contains all the changes to the storage and transactions to apply theses changes to the backend.
Fields
main_storage_changes: StorageCollectionAll changes to the main storage.
A value of None means that it was deleted.
child_storage_changes: ChildStorageCollectionAll changes to the child storages.
offchain_storage_changes: OffchainChangesCollectionOffchain state changes to write to the offchain database.
transaction: TransactionA transaction for the backend that contains all changes from
main_storage_changes and from
child_storage_changes.
offchain_storage_changes.
transaction_storage_root: H::OutThe storage root after applying the transaction.
changes_trie_transaction: Option<ChangesTrieTransaction<H, N>>Contains the transaction for the backend for the changes trie.
If changes trie is disabled the value is set to None.
Implementations
Sourceimpl<Transaction, H: Hasher, N: BlockNumber> StorageChanges<Transaction, H, N>
impl<Transaction, H: Hasher, N: BlockNumber> StorageChanges<Transaction, H, N>
Sourcepub fn into_inner(
self,
) -> (StorageCollection, ChildStorageCollection, OffchainChangesCollection, Transaction, H::Out, Option<ChangesTrieTransaction<H, N>>)
pub fn into_inner( self, ) -> (StorageCollection, ChildStorageCollection, OffchainChangesCollection, Transaction, H::Out, Option<ChangesTrieTransaction<H, N>>)
Deconstruct into the inner values