pub struct TestExternalities<H: Hasher, N: ChangesTrieBlockNumber = u64>{ /* private fields */ }Expand description
Simple HashMap-based Externalities impl.
Implementations
Sourceimpl<H: Hasher, N: ChangesTrieBlockNumber> TestExternalities<H, N>
impl<H: Hasher, N: ChangesTrieBlockNumber> TestExternalities<H, N>
Sourcepub fn ext(&mut self) -> Ext<'_, H, N, InMemoryBackend<H>>
pub fn ext(&mut self) -> Ext<'_, H, N, InMemoryBackend<H>>
Get externalities implementation.
Sourcepub fn new_with_code(code: &[u8], storage: Storage) -> Self
pub fn new_with_code(code: &[u8], storage: Storage) -> Self
Create a new instance of TestExternalities with code and storage.
Sourcepub fn overlayed_changes(&self) -> &OverlayedChanges
pub fn overlayed_changes(&self) -> &OverlayedChanges
Returns the overlayed changes.
Sourcepub fn persist_offchain_overlay(&mut self)
pub fn persist_offchain_overlay(&mut self)
Move offchain changes from overlay to the persistent store.
Sourcepub fn offchain_db(&self) -> TestPersistentOffchainDB
pub fn offchain_db(&self) -> TestPersistentOffchainDB
A shared reference type around the offchain worker storage.
Sourcepub fn insert(&mut self, k: StorageKey, v: StorageValue)
pub fn insert(&mut self, k: StorageKey, v: StorageValue)
Insert key/value into backend
Sourcepub fn register_extension<E: Any + Extension>(&mut self, ext: E)
pub fn register_extension<E: Any + Extension>(&mut self, ext: E)
Registers the given extension for this instance.
Sourcepub fn changes_trie_storage(&mut self) -> &mut ChangesTrieInMemoryStorage<H, N>
pub fn changes_trie_storage(&mut self) -> &mut ChangesTrieInMemoryStorage<H, N>
Get mutable reference to changes trie storage.
Sourcepub fn commit_all(&mut self) -> Result<(), String>
pub fn commit_all(&mut self) -> Result<(), String>
Commit all pending changes to the underlying backend.
Panic
This will panic if there are still open transactions.
Sourcepub fn execute_with<R>(&mut self, execute: impl FnOnce() -> R) -> R
pub fn execute_with<R>(&mut self, execute: impl FnOnce() -> R) -> R
Execute the given closure while self is set as externalities.
Returns the result of the given closure.
Sourcepub fn execute_with_safe<R>(
&mut self,
f: impl FnOnce() -> R + UnwindSafe,
) -> Result<R, String>
pub fn execute_with_safe<R>( &mut self, f: impl FnOnce() -> R + UnwindSafe, ) -> Result<R, String>
Execute the given closure while self is set as externalities.
Returns the result of the given closure, if no panics occured.
Otherwise, returns Err.