pub struct TrieBackend<S: TrieBackendStorage<H>, H: Hasher> { /* private fields */ }Expand description
Patricia trie-based backend. Transaction type is an overlay of changes to commit.
Implementations
Sourceimpl<H: Hasher> TrieBackend<MemoryDB<H>, H>
impl<H: Hasher> TrieBackend<MemoryDB<H>, H>
Sourcepub fn update<T: IntoIterator<Item = (Option<ChildInfo>, StorageCollection)>>(
&self,
changes: T,
) -> Self
pub fn update<T: IntoIterator<Item = (Option<ChildInfo>, StorageCollection)>>( &self, changes: T, ) -> Self
Copy the state, with applied updates
Sourcepub fn insert<T: IntoIterator<Item = (Option<ChildInfo>, StorageCollection)>>(
&mut self,
changes: T,
)
pub fn insert<T: IntoIterator<Item = (Option<ChildInfo>, StorageCollection)>>( &mut self, changes: T, )
Insert values into backend trie.
Sourcepub fn update_backend(&self, root: H::Out, changes: MemoryDB<H>) -> Self
pub fn update_backend(&self, root: H::Out, changes: MemoryDB<H>) -> Self
Merge trie nodes into this backend.
Sourcepub fn apply_transaction(&mut self, root: H::Out, transaction: MemoryDB<H>)
pub fn apply_transaction(&mut self, root: H::Out, transaction: MemoryDB<H>)
Apply the given transaction to this backend and set the root to the given value.
Sourceimpl<S: TrieBackendStorage<H>, H: Hasher> TrieBackend<S, H>
impl<S: TrieBackendStorage<H>, H: Hasher> TrieBackend<S, H>
Sourcepub fn backend_storage(&self) -> &S
pub fn backend_storage(&self) -> &S
Get backend storage reference.
Sourcepub fn backend_storage_mut(&mut self) -> &mut S
pub fn backend_storage_mut(&mut self) -> &mut S
Get backend storage reference.
Sourcepub fn into_storage(self) -> S
pub fn into_storage(self) -> S
Consumes self and returns underlying storage.